.. index::
    single: pcreate; --help

.. _pcreate_script:

.. autoprogram:: pyramid.scripts.pcreate:PCreateCommand.parser
    :prog: pcreate

.. seealso:: :ref:`creating_a_project` and :ref:`running-pscripts`.
